nsd_platform_interface library

Classes

Discovery
Represents a discovery.
NsdPlatformInterface
Registration
Represents a registration.
Service
Represents a network service.

Enums

ErrorCause
Indicates the cause of an NsdError.
IpLookupType
Configures IP lookup.
LogTopic
Represents available log topics.
ServiceStatus
Indicates the discovery status of a service.

Functions

isSame(Service a, Service b) → bool
Returns true if the two Service instances refer to the same service.
merge(Service existing, Service incoming) → Service
Merges two Service by overwriting existing attributes where new values are incoming.

Typedefs

ServiceListener = FutureOr<void> Function(Service service, ServiceStatus status)

Exceptions / Errors

NsdError
Represents an error that occurred during an NSD operation.